<?php

namespace Asadi\Feestructure\Http\Controllers;

use App\Http\Controllers\UserController as BaseController;
use Form;
use Asadi\Feestructure\Http\Requests\FeestructureRequest;
use Asadi\Feestructure\Interfaces\FeestructureRepositoryInterface;
use Asadi\Feestructure\Models\Feestructure;

class FeestructureUserController extends BaseController
{
    /**
     * Initialize feestructure controller.
     *
     * @param type FeestructureRepositoryInterface $feestructure
     *
     * @return type
     */
    public function __construct(FeestructureRepositoryInterface $feestructure)
    {
        $this->repository = $feestructure;
        $this->repository
                ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
                ->pushCriteria(new \Asadi\Feestructure\Repositories\Criteria\FeestructureUserCriteria());
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(FeestructureRequest $request)
    {
        $feestructures = $this->repository->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();

        $this->theme->prependTitle(trans('feestructure::feestructure.names'));

        return $this->theme->of('feestructure::user.feestructure.index', compact('feestructures'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param Feestructure $feestructure
     *
     * @return Response
     */
    public function show(FeestructureRequest $request, Feestructure $feestructure)
    {
        Form::populate($feestructure);

        return $this->theme->of('feestructure::user.feestructure.show', compact('feestructure'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(FeestructureRequest $request)
    {

        $feestructure = $this->repository->newInstance([]);
        Form::populate($feestructure);

        $this->theme->prependTitle(trans('feestructure::feestructure.names'));
        return $this->theme->of('feestructure::user.feestructure.create', compact('feestructure'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(FeestructureRequest $request)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $feestructure = $this->repository->create($attributes);

            return redirect(trans_url('/user/feestructure/feestructure'))
                -> with('message', trans('messages.success.created', ['Module' => trans('feestructure::feestructure.name')]))
                -> with('code', 201);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param Feestructure $feestructure
     *
     * @return Response
     */
    public function edit(FeestructureRequest $request, Feestructure $feestructure)
    {

        Form::populate($feestructure);
        $this->theme->prependTitle(trans('feestructure::feestructure.names'));

        return $this->theme->of('feestructure::user.feestructure.edit', compact('feestructure'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param Feestructure $feestructure
     *
     * @return Response
     */
    public function update(FeestructureRequest $request, Feestructure $feestructure)
    {
        try {
            $this->repository->update($request->all(), $feestructure->getRouteKey());

            return redirect(trans_url('/user/feestructure/feestructure'))
                ->with('message', trans('messages.success.updated', ['Module' => trans('feestructure::feestructure.name')]))
                ->with('code', 204);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(FeestructureRequest $request, Feestructure $feestructure)
    {
        try {
            $this->repository->delete($feestructure->getRouteKey());
            return redirect(trans_url('/user/feestructure/feestructure'))
                ->with('message', trans('messages.success.deleted', ['Module' => trans('feestructure::feestructure.name')]))
                ->with('code', 204);

        } catch (Exception $e) {

            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);

        }
    }
}
