<?php

namespace Asadi\Feestructure\Http\Controllers;
use Litepie\Feestructure\Http\Requests\FeestructureRequest;
use Litepie\Feestructure\Models\Feestructure;

trait FeestructureWorkflow {
	
    /**
     * Workflow controller function for feestructure.
     *
     * @param Model   $feestructure
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(FeestructureRequest $request, Feestructure $feestructure, $step)
    {

        try {

            $feestructure->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('feestructure::feestructure.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/feestructure/feestructure/' . $feestructure->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/feestructure/feestructure/' . $feestructure->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for feestructure.
     *
     * @param Model   $feestructure
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Feestructure $feestructure, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $feestructure->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('feestructure::feestructure.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('feestructure::admin.feestructure.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('feestructure::admin.feestructure.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('feestructure::admin.feestructure.message', $data)->render();

        }

    }
}