<?php

namespace Asadi\Feestructure\Policies;

use App\User;
use Asadi\Feestructure\Models\Feestructure;

class FeestructurePolicy
{

    /**
     * Determine if the given user can view the feestructure.
     *
     * @param User $user
     * @param Feestructure $feestructure
     *
     * @return bool
     */
    public function view(User $user, Feestructure $feestructure)
    {
        if ($user->canDo('feestructure.feestructure.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $feestructure->user_id;
    }

    /**
     * Determine if the given user can create a feestructure.
     *
     * @param User $user
     * @param Feestructure $feestructure
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('feestructure.feestructure.create');
    }

    /**
     * Determine if the given user can update the given feestructure.
     *
     * @param User $user
     * @param Feestructure $feestructure
     *
     * @return bool
     */
    public function update(User $user, Feestructure $feestructure)
    {
        if ($user->canDo('feestructure.feestructure.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $feestructure->user_id;
    }

    /**
     * Determine if the given user can delete the given feestructure.
     *
     * @param User $user
     * @param Feestructure $feestructure
     *
     * @return bool
     */
    public function destroy(User $user, Feestructure $feestructure)
    {
        if ($user->canDo('feestructure.feestructure.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $feestructure->user_id;
    }

    /**
     * Determine if the given user can verify the given feestructure.
     *
     * @param User $user
     * @param Feestructure $feestructure
     *
     * @return bool
     */
    public function verify(User $user, Feestructure $feestructure)
    {
        if ($user->canDo('feestructure.feestructure.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('feestructure.feestructure.verify') 
        && $user->is('manager')
        && $feestructure->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given feestructure.
     *
     * @param User $user
     * @param Feestructure $feestructure
     *
     * @return bool
     */
    public function approve(User $user, Feestructure $feestructure)
    {
        if ($user->canDo('feestructure.feestructure.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
