<?php

namespace Asadi\Feestructure\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Asadi\Feestructure\Models\Feestructure;

class FeestructureAction
{
    /**
     * Perform the complete action.
     *
     * @param Feestructure $feestructure
     *
     * @return Feestructure
     */
    public function complete(Feestructure $feestructure)
    {
        try {
            $feestructure->status = 'complete';
            return $feestructure->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Feestructure $feestructure
     *
     * @return Feestructure
     */public function verify(Feestructure $feestructure)
    {
        try {
            $feestructure->status = 'verify';
            return $feestructure->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Feestructure $feestructure
     *
     * @return Feestructure
     */public function approve(Feestructure $feestructure)
    {
        try {
            $feestructure->status = 'approve';
            return $feestructure->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Feestructure $feestructure
     *
     * @return Feestructure
     */public function publish(Feestructure $feestructure)
    {
        try {
            $feestructure->status = 'publish';
            return $feestructure->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Feestructure $feestructure
     *
     * @return Feestructure
     */
    public function archive(Feestructure $feestructure)
    {
        try {
            $feestructure->status = 'archive';
            return $feestructure->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Feestructure $feestructure
     *
     * @return Feestructure
     */
    public function unpublish(Feestructure $feestructure)
    {
        try {
            $feestructure->status = 'unpublish';
            return $feestructure->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
