<?php

namespace Asadi\Feestructure\Workflow;

use Asadi\Feestructure\Models\Feestructure;
use Validator;

class FeestructureValidator
{

    /**
     * Determine if the given feestructure is valid for complete status.
     *
     * @param Feestructure $feestructure
     *
     * @return bool / Validator
     */
    public function complete(Feestructure $feestructure)
    {
        return Validator::make($feestructure->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given feestructure is valid for verify status.
     *
     * @param Feestructure $feestructure
     *
     * @return bool / Validator
     */
    public function verify(Feestructure $feestructure)
    {
        return Validator::make($feestructure->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given feestructure is valid for approve status.
     *
     * @param Feestructure $feestructure
     *
     * @return bool / Validator
     */
    public function approve(Feestructure $feestructure)
    {
        return Validator::make($feestructure->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given feestructure is valid for publish status.
     *
     * @param Feestructure $feestructure
     *
     * @return bool / Validator
     */
    public function publish(Feestructure $feestructure)
    {
        return Validator::make($feestructure->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given feestructure is valid for archive status.
     *
     * @param Feestructure $feestructure
     *
     * @return bool / Validator
     */
    public function archive(Feestructure $feestructure)
    {
        return Validator::make($feestructure->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given feestructure is valid for unpublish status.
     *
     * @param Feestructure $feestructure
     *
     * @return bool / Validator
     */
    public function unpublish(Feestructure $feestructure)
    {
        return Validator::make($feestructure->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
